SystemOrganization addCategory: #'Zinc-Tests-Old'!
SystemOrganization addCategory: #'Zinc-Tests-New'!

TestCase subclass: #ZnChunkedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:07'!
testReading
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	self assert: plain = data! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:18'!
testReadingGzip
	| data gzipped chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	plain := (GZipReadStream on: (ZnChunkedReadStream on: chunked readStream)) upToEnd.
	self assert: data = plain ! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:17'!
testReadingGzipStepped
	| data gzipped chunked unchunked ungzipped |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	unchunked := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	ungzipped := (GZipReadStream on: unchunked) upToEnd.
	self assert: gzipped = unchunked.
	self assert: data = ungzipped ! !

TestCase subclass: #ZnClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/21/2010 11:04'!
testDelete
	| server response |
	server := ZnServer on: 1701.
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		response := ZnClient delete: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'DELETE').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 16:12'!
testGetJpeg
	| url result |
	url := 'http://caretaker.wolf359.be/sun-fire-x2100.jpg' asUrl.
	result := ZnClient getJpeg: url.
	self assert: result isForm! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/7/2010 19:57'!
testGetSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html' asUrl.
	response := ZnClient get: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small')! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/21/2010 12:19'!
testHeadSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html' asUrl.
	response := ZnClient head: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: response hasEntity not! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/21/2010 12:20'!
testPost
	| server response data |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		response := ZnClient post: 'http://localhost:1701/echo/foo' data: (ZnStringEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'POST').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/21/2010 12:21'!
testPut
	| server response data |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		response := ZnClient put: 'http://localhost:1701/echo/foo' data: (ZnStringEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'PUT').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnCredentialTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/30/2010 15:53'!
testBasicAuthorization
	| server response client cred |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		client logProgressToTranscript.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'secret';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 200).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 12:56'!
testBasicAuthorizationFailure
	| server response client cred |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		client logProgressToTranscript.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'wrong';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 401).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 17:40'!
testDigestAuthorization
	| server response client cred |
	self assert: ZnDigestAuthenticator hasMD5Support description: 'MD5 hashing support is required for Digest authentication.'.
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		client logProgressToTranscript.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Digest').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'secret';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 200).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 17:40'!
testDigestAuthorizationFailure
	| server response client cred |
	self assert: ZnDigestAuthenticator hasMD5Support description: 'MD5 hashing support is required for Digest authentication.'.
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		client logProgressToTranscript.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Digest').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'wrong';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 401).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/30/2010 15:53'!
testFindHandlerFor
	| server response client handler |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		client logProgressToTranscript.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		handler := ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate').
		self assert: (handler = ZnBasicCredential).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/30/2010 15:53'!
testFindRealmFor
	| server response client realm |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		client logProgressToTranscript.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		realm := ZnCredential findRealmFor: (response headers at: 'WWW-Authenticate').
		self assert: (realm includesSubString: 'Zinc').
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'MattKennedy 9/30/2010 16:02'!
testZnServerBasicAuthRealm
	| server response client cred |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		client logProgressToTranscript.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'secret';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		self assert: (cred realm = 'TEST').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 200).
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnEntityReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/26/2010 19:58'!
testChunked
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/26/2010 20:00'!
testChunkedWithExtraHeaders
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, 
		'X-Foo:bar', String crlf, 
		String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'.
	self assert: (headers at: 'X-Foo') = 'bar'! !

TestCase subclass: #ZnEntityTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 16:13'!
testReading
	| contents entity |
	contents := 'This is a test'.
	entity := ZnEntity 
				readFrom: contents readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size.
	self assert: entity isBinary not.
	self assert: entity string = contents.
	self assert: entity contentLength = contents size.
	self assert: entity contentType = ZnMimeType textPlain ! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 10:11'!
testWritingApplicationUrlEncoding
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity at: 'foo' put: 'bar'.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=bar'.
	self assert: entity contentLength = 7! !

TestCase subclass: #ZnFixedClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnFixedClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/28/2010 12:58'!
testGetSmallHTMLDocument
	| client response |
	client := ZnFixedClient host:	 'homepage.mac.com'.
	[
	response := client get: '/svc/Zinc-HTTP-Components/small.html'.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small') ] 
		ensure: [ client close ]! !

TestCase subclass: #ZnHTTPSocketFacadeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:17'!
testGetSmallHTMLDocument
	| mimeDocument |
	mimeDocument := ZnHTTPSocketFacade httpGetDocument: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (mimeDocument contents includesSubString: 'small').
	self assert: (mimeDocument contentType includesSubString: 'text/html')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:18'!
testGetSmallHTMLStream
	| stream |
	stream := ZnHTTPSocketFacade httpGet: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (stream contents includesSubString: 'small')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/30/2010 15:55'!
testPut
	| server result dataString |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'user' password: 'secret').
	dataString := String streamContents: [ :stream | 
		1 to: 67 do: [ :each | stream nextPut: (Character digitValue: each \\ 9) ] ].
	[ 
		server start.
		result := ZnHTTPSocketFacade httpPut: dataString to: 'http://localhost:1701/echo/foo' user: 'user' passwd: 'secret'.
		self assert: (result beginsWith: 'HTTP/1.1 200 OK').
		self assert: (result includesSubString: 'length 67')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnHeadersTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:59'!
testMergeValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' put: 'bar=1' ifPresentMerge: [ :old :new | old, ';', new ].
	self assert: (headers at: 'Set-Cookie') = 'foo=1;bar=1'
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:57'!
testMultiValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	self assert: (headers at: 'Set-Cookie') = #('foo=1' 'bar=1')
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 21:03'!
testMultiValuedStreaming
	| headers keysAndValues |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	keysAndValues := OrderedCollection streamContents: [ : stream |
		headers headersDo: [ :key :value |
			stream nextPut: key; nextPut: value ] ].
	self assert: keysAndValues  = #('Set-Cookie' 'foo=1' 'Set-Cookie' 'bar=1') asOrderedCollection 
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:55'!
testNormalization
	| headers |
	headers := ZnHeaders new.
	headers at: 'content-TYPE' put: 'text/plain'.
	self assert: (headers includesKey: 'content-type').
	self assert: (headers includesKey: 'content-TYPE').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	headers at: 'CONTENT-type' put: 'text/html'.
	self assert: (headers at: 'Content-Type') = 'text/html'.

	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:16'!
testReading
	| string headers |
	string := 'Content-Type: text/plain', String crlf, 'Content-Length: 128', String crlf.
	headers := ZnHeaders readFrom: string readStream.
	self assert: (headers includesKey: 'Content-Type').
	self assert: (headers includesKey: 'Content-Length').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	self assert: (headers at: 'Content-Length') = '128'.! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:20'!
testWriting
	| headers string |
	headers := ZnHeaders new 
		at: 'Content-Type' put: 'text/plain'; 
		at: 'Content-Length' put: '128';
		yourself.
	string := String streamContents: [ :stream | headers writeOn: stream ].
	self assert: (string includesSubString: 'Content-Type: text/plain', String crlf).
	self assert: (string includesSubString: 'Content-Length: 128', String crlf).
	self assert: (string occurrencesOf: Character cr) = 2.
	self assert: (string occurrencesOf: Character lf) = 2! !

TestCase subclass: #ZnHttpClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:45'!
testBasicAuthorization
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			auth: 'foo' password: 'secret'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:57'!
testBasicAuthorizationFailure
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			auth: 'foo' password: 'wrong'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client isAuthRequired).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:26'!
testCookieAt
	| client response |
	client := ZnHttpClient new url: 'pharo-project.org'.
	response := client get.
	self assert: ((client cookieAt: 'cmsbox') notNil)! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:06'!
testDelete
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnHttpClient new
					url: 'http://localhost:1701/echo/foo'.
		response := client delete.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
		self assert: (response  includesSubString: 'DELETE').
		self assert: (response  includesSubString: 'DELETE')
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:56'!
testDigestAuthorization
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			digestAuth: 'foo' password: 'secret'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:56'!
testDigestAuthorizationFailure
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			digestAuth: 'foo' password: 'wrong'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client isAuthRequired).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 20:59'!
testGet
	| client response |
	client := ZnHttpClient new.
	response := client 
		url: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html';
		get.
	self assert: response notNil.
	self assert: (client status = 200)! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:06'!
testPost
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnHttpClient new
					url: 'http://localhost:1701/echo/foo';
					parameterAt: 'foo' put: 'bar';
					parameterAt: 'baz' put: 'bang'. 
		response := client post.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
		self assert: (response  includesSubString: 'POST').
		self assert: (response  includesSubString: 'bar')
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 21:08'!
testPut
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnHttpClient new
					url: 'http://localhost:1701/echo/foo';
					parameterAt: 'foo' put: 'bar';
					parameterAt: 'baz' put: 'bang'. 
		response := client put.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
		self assert: (response  includesSubString: 'PUT')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnLimitedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 13:04'!
testSimple
	| data limitedReadStream |
	data := '0123456789'.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: limitedReadStream upToEnd = '01234'! !

TestCase subclass: #ZnLineReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:22'!
testBinary
	| input reader |
	input := ('Foo', String crlf, 'Bar', String crlf) asByteArray.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:02'!
testSimple
	| input reader |
	input := 'Foo', String crlf, 'Bar', String crlf.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

TestCase subclass: #ZnMagicCookieJarTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:25'!
cookieString
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.google.com'! !

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:31'!
cookieStringAlt
	^'PREFS=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.pharo-project.org'! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 16:27'!
testAdd
	| jar count |
	jar := ZnMagicCookieJar new.
	count := jar cookies size.
	jar add: (ZnMagicCookie fromString: self cookieString for: 'www.google.com' asUrl).
	self assert: ((jar cookies size) = (count + 1))! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 16:32'!
testCookieAtForUrl
	| jar c1 c2 |
	jar := ZnMagicCookieJar new.
	c1 := ZnMagicCookie fromString: self cookieString for: 'www.google.com' asUrl.
	c2 := ZnMagicCookie fromString: self cookieStringAlt for: 'www.pharo-project.org' asUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookieAt: 'PREF' forUrl: 'www.google.com' asUrl) notNil).
	self assert: ((jar cookieAt: 'foobar' forUrl: 'www.google.com' asUrl) isNil)! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 16:29'!
testCookiesForUrl
	| jar c1 c2 |
	jar := ZnMagicCookieJar new.
	c1 := ZnMagicCookie fromString: self cookieString for: 'www.google.com' asUrl.
	c2 := ZnMagicCookie fromString: self cookieStringAlt for: 'www.pharo-project.org' asUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookiesForUrl: 'www.google.com' asUrl) size = 1)! !

TestCase subclass: #ZnMagicCookieTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnMagicCookieTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 15:16'!
cookieString
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.google.com'! !

!ZnMagicCookieTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:11'!
cookieStringSubpath
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/test/; domain=.google.com'! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:21'!
testFromString
	| cookie |
	cookie := ZnMagicCookie fromString: self cookieString for: 'www.google.com' asUrl.
	self assert: (cookie name = 'PREF').
	self assert: (cookie path notNil).
	self assert: (cookie domain = '.google.com').
	self assert: (cookie isExpired not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:21'!
testInDomain
	| cookie |
	cookie := ZnMagicCookie fromString: self cookieString for: 'www.google.com' asUrl.
	self assert: (cookie isInDomain: 'www.google.com' asUrl).
	self assert: (cookie isInDomain: 'google.com' asUrl).
	self assert: ((cookie isInDomain: 'pharo-project.org' asUrl) not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 16:12'!
testInPath
	| cookie |
	cookie := ZnMagicCookie fromString: self cookieStringSubpath for: 'www.google.com' asUrl.
	self assert: (cookie isInPath: 'www.google.com/test/' asUrl).
	self assert: ((cookie isInPath: 'www.google.com' asUrl) not)
	! !

TestCase subclass: #ZnMimeTypeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:45'!
testDefault
	self assert: ZnMimeType default = ZnMimeType applicationOctetStream.
	self assert: ZnMimeType default == ZnMimeType applicationOctetStream! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:44'!
testIdentity
	self assert: ZnMimeType textPlain = ZnMimeType textPlain.
	self assert: ZnMimeType textPlain == ZnMimeType textPlain! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 07:27'!
testReading
	| mimeType |
	mimeType := ZnMimeType fromString: 'text/plain; charset=utf-8'.
	self assert: (mimeType main = 'text').
	self assert: (mimeType sub = 'plain').
	self assert: (mimeType charSet = 'utf-8').
	self assert: mimeType isBinary not! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 07:29'!
testWriting
	| mimeType |
	(mimeType := ZnMimeType main: 'text' sub: 'plain')
		charset: 'utf-8'.
	self assert: mimeType printString = 'text/plain;charset=utf-8'.
	self assert: mimeType isBinary not! !

TestCase subclass: #ZnOldHTTPMethodTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-Old'!

!ZnOldHTTPMethodTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:39'!
testGetSmallHTMLDocument
	| doc url |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html' asUrl.
	doc := ZnOldHTTPSocketFacade httpGetDocument: url.
	self assert: (doc mimeType = MIMEType defaultHTML).
	self assert: (doc uri = url).
	self assert: (doc contents includesSubString: 'small')! !

TestCase subclass: #ZnRequestLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:08'!
testReading
	| requestLine string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.1', String crlf.
	requestLine := ZnRequestLine readFrom: string readStream.
	self assert: requestLine method = #GET.
	self assert: requestLine uriPathQueryFragment = '/foo/bar/xyz.txt'.
	self assert: requestLine version = ZnConstants defaultHTTPVersion ! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:11'!
testWriting
	| requestLine string |
	requestLine := ZnRequestLine method: 'GET' uri: '/foo/bar/xyz.txt'.
	string := String streamContents: [ :stream | requestLine writeOn: stream ].
	self assert: string = ('GET /foo/bar/xyz.txt HTTP/1.1', String crlf)! !

TestCase subclass: #ZnRequestTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 20:25'!
testBasicAuthenticate
	| request |
	request := ZnRequest new.
	request setBasicAuthenticationUsername: 'user' password: 'secret'.
	self assert: (request headers at: 'Authorization') = 'Basic dXNlcjpzZWNyZXQ='! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/25/2010 22:59'!
testReading
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Agent: SUnit', String crlf, 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	self assert: request method = #GET.
	self assert: (request headers at: 'Host') = 'foo.com'.
	self assert: request entity isNil
! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/25/2010 23:01'!
testReadingWithEntity
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Content-Length: 8', String crlf, 
		'Content-Type: text/plain', String crlf, 
		String crlf, 
		'12345678'.
	request := ZnRequest readFrom: input readStream.
	self assert: request method = #GET.
	self assert: request contentType = ZnMimeType textPlain.
	self assert: request contentLength = 8.
	self assert: request entity contents = '12345678'
! !

TestCase subclass: #ZnResponseTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 15:37'!
testCreated
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse created: uri asUrl.
	self assert: response code = 201.
	self assert: (response headers at: 'Location') = uri.
	self assert: (response entity contents includesSubString: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 15:38'!
testNotFound
	| response |
	response := ZnResponse notFound: 'http:///secret.txt' asUrl.
	self assert: response code = 404.
	self assert: (response headers includesKey: 'Server').
	self assert: (response headers includesKey: 'Date').
	self assert: (response entity contents includesSubString: 'secret.txt')! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 15:37'!
testRedirect
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse redirect: uri asUrl.
	self assert: response code = 302.
	self assert: (response headers at: 'Location') = uri.
	self assert: (response entity contents includesSubString: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/28/2010 16:00'!
testSlashdotGzipChunked
	| request stream response gzip |
	(request := ZnRequest get: 'http://slashdot.org')
		setConnectionClose;
		setAcceptEncodingGzip.
	stream := ZnUtils socketStreamToUrl: request url.
	response := [ 
  		request writeOn: stream. 
  		stream flush. 
  		ZnResponse readFrom: stream ] ensure: [ stream close ].
	self assert: response code = 200.
	self assert: ((response headers at: 'Content-Type') beginsWith: 'text/html').
	self assert: (response headers at: 'Content-Encoding' ifAbsent: [ 'gzip' ]) = 'gzip'.
	self assert: (response headers at: 'Transfer-Encoding' ifAbsent: [ 'chunked' ]) = 'chunked'.
	self assert: (response entity contents includesSubString: 'Slashdot')
! !

TestCase subclass: #ZnServerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/30/2010 15:54'!
testAuthorizationFailed
	| server response |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		response := ZnClient get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Zinc')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/30/2010 15:54'!
testAuthorizationSuccessful
	| server response |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		response := ZnClient get: 'http://localhost:1701/echo/foo' username: 'foo' password: 'secret'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'Zinc').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/16/2010 11:35'!
testEcho
	| server response |
	server := ZnServer on: 1701.
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		response := ZnClient get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'Zinc').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnStatusLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:09'!
testReading
	| statusLine string |
	string := 'HTTP/1.1 200 OK', String crlf.
	statusLine := ZnStatusLine readFrom: string readStream.
	self assert: statusLine code = 200.
	self assert: statusLine reason = 'OK'.
	self assert: statusLine version = ZnConstants defaultHTTPVersion ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:11'!
testWriting
	| statusLine string |
	statusLine := ZnStatusLine code: 200.
	string := String streamContents: [ :stream | statusLine writeOn: stream ].
	self assert: string = ('HTTP/1.1 200 OK', String crlf)! !

TestCase subclass: #ZnUserAgentSessionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnUserAgentSessionTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 15:11'!
dummyCredential
	^ZnBasicCredential new 
		username: 'test'; 
		password: 'foobar';
		realm: 'dummy';
		domain: 'test.com';
		yourself! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:06'!
testAccessors
	| session |
	session := ZnUserAgentSession new.
	self assert: (session cookiejar isKindOf: ZnMagicCookieJar).
	self assert: (session credentials notNil)! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:14'!
testAddCredential
	| session count |
	session := ZnUserAgentSession new.
	count := session credentials size.
	session addCredential: self dummyCredential.
	self assert: ((session credentials size) = (count + 1))! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:15'!
testWithCookieJar
	self assert: ((ZnUserAgentSession withCookieJar: ZnMagicCookieJar new) notNil)! !

TestCase subclass: #ZnUserAgentSettingsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 14:58'!
testAccessors
	| settings |
	settings := ZnUserAgentSettings defaultSettingsClass new.
	self assert: (settings agent notNil).
	self assert: (settings followRedirect isKindOf: Boolean).
	self assert: (settings redirectLimit notNil).
	self assert: (settings timeout notNil)! !

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:00'!
testClassDefaults
	self assert: (ZnUserAgentSettings defaultCookieJar new isKindOf: ZnMagicCookieJar).
	self assert: (ZnUserAgentSettings defaultSessionClass new isKindOf: ZnUserAgentSession).
	self assert: (ZnUserAgentSettings defaultSettingsClass new isKindOf: ZnUserAgentSettings)! !

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 14:59'!
testLoadSession
	| settings |
	settings := ZnUserAgentSettings defaultSettingsClass new.
	self assert: (settings loadSession isKindOf: ZnUserAgentSession)! !

TestCase subclass: #ZnUserAgentTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 14:16'!
testCookieAt
	| url client response |
	url := 'http://www.google.com/' asUrl.
	client := ZnUserAgent new.
	response := client get: url.
	self assert: ((client cookieAt: 'PREF') notNil)! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 9/27/2010 15:03'!
testDelete
	| server response client |
	server := ZnServer on: 1701.
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		response := client delete: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'DELETE').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 14:41'!
testErrorHandler
	| client flag |
	flag := false.
	client := ZnUserAgent new 
				logProgressToTranscript;
				errorHandler: [:error | flag := true ].
	client get: ''.
	self assert: flag! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 13:50'!
testFollowRedirect
	| url client response |
	url := 'http://pharo-project.org/' asUrl.
	client := ZnUserAgent new.
	client settings followRedirect: false.
	response := client get: url.
	self assert: (client isRedirect: response statusLine code).
	client settings followRedirect: true.
	response := client get: url.
	self assert: (response statusLine code = 200)! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 9/27/2010 14:59'!
testGetSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html' asUrl.
	response := ZnUserAgent new get: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small')! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 9/27/2010 14:59'!
testHeadSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html' asUrl.
	response := ZnUserAgent new head: url.
	self assert: response headers contentType = ZnMimeType textHtml.
	self assert: response statusLine code = 200! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 9/27/2010 14:56'!
testPost
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		response := client post: 'http://localhost:1701/echo/foo' data: (ZnStringEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'POST').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'MattKennedy 9/27/2010 14:56'!
testPut
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		response := client put: 'http://localhost:1701/echo/foo' data: (ZnStringEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'PUT').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnUtilsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:44'!
testAsMimeType
	self assert: (ZnUtils asMimeType: 'text/plain') = ZnMimeType textPlain.
	self assert: (ZnUtils asMimeType: ZnMimeType applicationOctetStream) = ZnMimeType applicationOctetStream
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:09'!
testCapitalizeString
	self assert: (ZnUtils capitalizeString: 'content-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'CONTENT-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'content-TYPE') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'WWW-Authenticate') = 'Www-Authenticate'.
	self assert: (ZnUtils capitalizeString: 'Content-MD5') = 'Content-Md5'.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 15:05'!
testHostAndPortOf
	self assert: ((ZnUtils hostAndPortOf: 'http://localhost:8080/foo/bar/doc.txt' asUrl) = 'localhost:8080').
	self assert: ((ZnUtils hostAndPortOf: 'http://www.google.com?q=Smalltalk' asUrl) = 'www.google.com')! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:52'!
testHttpDate
	| timestamp string |
	timestamp := (DateAndTime year: 2010 month: 9 day: 1 hour: 10 minute: 10 second: 10 offset: 0).
	string := ZnUtils httpDate: timestamp.
	self assert: (string = 'Wed, 01 Sep 2010 10:10:10 GMT')
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:10'!
testIsCapitalizedString
	self assert: (ZnUtils isCapitalizedString: 'Content-Type').
	self assert: (ZnUtils isCapitalizedString: 'CONTENT-type') not.
	self assert: (ZnUtils isCapitalizedString: 'content-TYPE') not.
	self assert: (ZnUtils isCapitalizedString: 'WWW-Authenticate') not.
	self assert: (ZnUtils isCapitalizedString: 'Connection')! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 15:04'!
testIsSlash
	self assert: (ZnUtils isSlash: '' asUrl).
	self assert: (ZnUtils isSlash: '/' asUrl).
	self assert: (ZnUtils isSlash: '/foo' asUrl) not.
	self assert: (ZnUtils isSlash: 'http://host/foo' asUrl) not.
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/11/2010 21:36'!
testQueryParsing
	| string fields |
	string := 'foo=100&x=', ('/a b' encodeForHTTP).
	fields := ZnUtils parseQueryFrom: string readStream.
	self assert: (fields at: 'foo') = '100'.
	self assert: (fields at: 'x') = '/a b'.
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:55'!
testQueryWriting
	| fields string |
	(fields := Dictionary new)
		at: 'foo' put: '100';
		at: 'bar' put: 'a b'.
	string := String streamContents: [ :stream | ZnUtils writeQueryFields: fields on: stream ].
	self assert: (string includesSubString: 'foo=1').
	self assert: (string includesSubString: 'bar=a%20b').! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 16:14'!
testStreamingBinary
	| data in out |
	data := ByteArray streamContents: [ :stream | 1 to: 10000 do: [ :each | stream nextPut: #(1 2 3) atRandom ] ].
	in := data readStream.
	out := WriteStream on: (ByteArray new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 16:14'!
testStreamingNonBinary
	| data in out |
	data := String streamContents: [ :stream | 1 to: 10000 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	in := data readStream.
	out := WriteStream on: (String new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 15:02'!
testWriteUrlPathQueryFragmentOfOn
	| string |
	string := String streamContents: [ :stream |
		ZnUtils writeUrlPathQueryFragmentOf: 'http://host:7777/foo/bar/doc.txt?x=1#mark' asUrl on: stream ].
	self assert: string = '/foo/bar/doc.txt?x=1#mark'
! !
